@@ -110,7 +110,7 @@ class SdpRelaxation(object):
         """
         facvar = [0] * (self.n_vars + 1)
         # Preprocess the polynomial for uniform handling later
-        if isinstance(polynomial, Number) or isinstance(polynomial, float):
+        if isinstance(polynomial, Number) or isinstance(polynomial, float) or isinstance(polynomial, int):
             facvar[0] = polynomial
             return facvar
         polynomial = polynomial.expand()
@@ -173,6 +173,8 @@ class SdpRelaxation(object):
 
     def __simplify_polynomial(self, polynomial):
         # Preprocess the polynomial for uniform handling later
+        if isinstance(polynomial, int) or isinstance(polynomial, float):
+            return polynomial
         polynomial = (1.0 * polynomial).expand()
         if isinstance(polynomial, Number):
             return polynomial
@@ -380,6 +382,12 @@ class SdpRelaxation(object):
                                 self.F_struct[:, 1:].dot(H)])
         self.n_vars = self.F_struct.shape[1] - 1
 
+    def swap_objective(self, new_objective):
+        """Swaps the objective function while keeping the moment matrix and
+        the localizing matrices untouched"""
+        self.obj_facvar = (
+            self.__get_facvar(self.__simplify_polynomial(new_objective)))[1:]
+
     def __save_monomial_dictionary(self, filename):
         """Save the current monomial dictionary for debugging purposes.
         """
